#include <stdio.h>

static char version[] = "0.0.18 beta";

// 関数プロトタイプ
void help(void);

/*******************************************************************************
 * ヘルプ
*******************************************************************************/
void help()
{
	printf("バージョン %s\n", version);
	puts("使用方法 : fake-defrag-ext4 [option] folder");
	puts("floder内のファイルをデフラグする。folderは複数指定可能。");
	puts("");
	puts("オプション");
	puts(" -g    1GBを超えるファイルもデフラグの対象にする。");
	puts("");
	puts(" -G    1GBを超えるファイルのみをデフラグの対象にする。");
	puts("");
}
